@@ -12,7 +12,7 @@ import zipfile
 logger = logging.getLogger(__name__)
 
 rx_setuptools = re.compile(
-    os.path.join('^.*', '(setuptools|distribute)-.*?-py\d.\d.egg$'))
+    '^.*' + re.escape(os.sep) + '(setuptools|distribute)-.*?-py\d.\d.egg$')
 
 
 def copytree(src, dst, symlinks=0, allowed_basenames=None, exclude=[]):
@@ -110,9 +110,9 @@ class Recipe(zc.recipe.egg.Eggs):
                         ['executable'])
         script.write("import sys\nimport os\n\n")
         script.write("sys.path[0:0] = [\n")
-        script.write(",\n".join(["  '%s'" % p for p in sys_path]))
+        script.write(",\n".join(["  %r" % p for p in sys_path]))
         script.write("\n  ]\n\n")
-        script.write("PROJECT_HOME = '%s'\n\n" %
+        script.write("PROJECT_HOME = %r\n\n" %
                      self.buildout['buildout']['directory'])
         script.write("def mkvar():\n")
         script.write("  var = os.path.join(PROJECT_HOME, 'var')\n")
@@ -122,7 +122,7 @@ class Recipe(zc.recipe.egg.Eggs):
         script.write("from dev_appserver import *\n\n")
         script.write("if __name__ == '__main__':\n")
         script.write("  os.environ['TMPDIR'] = mkvar()\n")
-        script.write("  run_file('%s', locals())" % bin)
+        script.write("  run_file(%r, locals())" % bin)
 
         # Close script file and modify permissions
         script.close()
@@ -153,7 +153,7 @@ class Recipe(zc.recipe.egg.Eggs):
 
     def install_appengine(self):
         """Downloads and installs Google App Engine."""
-        arch_filename = self.options['url'].split(os.sep)[-1]
+        arch_filename = self.options['url'].split('/')[-1].split(os.sep)[-1]
         dst = os.path.join(self.buildout['buildout']['parts-directory'])
         downloads_dir = os.path.join(os.getcwd(), 'downloads')
         if not os.path.isdir(downloads_dir):
@@ -168,7 +168,7 @@ class Recipe(zc.recipe.egg.Eggs):
             shutil.rmtree(os.path.join(dst, 'google_appengine'))
         arch = zipfile.ZipFile(open(src, "rb"))
         for name in arch.namelist():
-            if name.endswith(os.sep):
+            if name and name[-1] in (os.sep, '/'):
                 os.mkdir(os.path.join(dst, name))
             else:
                 outfile = open(os.path.join(dst, name), 'wb')
@@ -252,7 +252,7 @@ class Recipe(zc.recipe.egg.Eggs):
             if not os.path.exists(dir) and os.path.exists(src):
                 os.mkdir(dir)
             exclude = ['EGG-INFO'] # Exclude this every time
-            copytree(src, dir, True,
+            copytree(src, dir, hasattr(os, 'symlink'),
                      allowed_basenames=allowed_basenames,
                      exclude=exclude+self.options.get('exclude', '').split())
 
@@ -281,7 +281,7 @@ class Recipe(zc.recipe.egg.Eggs):
             reqs, ws = self.working_set()
             sources = [d.location for d in ws if d.key in reqs]
         for s in sources:
-            copytree(s, options['app-directory'], True,
+            copytree(s, options['app-directory'], hasattr(os, 'symlink'),
                      exclude=options.get('exclude', '').split())
 
     def patch_sdk(self, patch_options, patch_file):
